# Python packaging references

[Packaging Python Projects](https://packaging.python.org/tutorials/packaging-projects/)

[How To Package Your Python Code](https://python-packaging.readthedocs.io/en/latest/)

[Less known packaging features and tricks presentation](https://blog.ionelmc.ro/presentations/packaging/)

# GitHub Action references

[Workflow syntax for GitHub Actions](https://docs.github.com/en/actions/reference/workflow-syntax-for-github-actions)

[Reference for building actions and creating workflows](https://docs.github.com/en/actions/reference)

[Using Python with GitHub Actions](https://help.github.com/en/actions/language-and-framework-guides/using-python-with-github-actions)

[Python Github Actions](https://github.com/actions/starter-workflows/tree/master/ci)

    https://github.com/actions/starter-workflows/blob/master/ci/python-app.yml
    older: https://github.com/macbre/sql-metadata/blob/master/.github/workflows/pythonapp.yml
    https://github.com/actions/starter-workflows/blob/master/ci/python-package.yml
    https://github.com/actions/starter-workflows/blob/master/ci/python-publish.yml
    
# TODO

1) Fix tox / flake8 / black? setup
1) Manifest file fixes
1) Ensure pypi source is compilable
1) Add / refactor tests
1) Set appropriate version & classifiers
1) Fix extras_require and test_requiremetns etc
1) Switch from test.pypi to pypi
1) Test pip install from pypi works
1) Github build and release actions to pypi
1) 
 